eric6/Globals/__init__.py

changeset 7835
0835ed67714b
parent 7805
3cad282e8409
child 7858
b8223c11fd4b
--- a/eric6/Globals/__init__.py	Thu Nov 19 17:41:58 2020 +0100
+++ b/eric6/Globals/__init__.py	Sat Nov 21 19:31:16 2020 +0100
@@ -316,7 +316,13 @@
     # step 1: check, if the user has configured a tools path
     path = Preferences.getQt("QtToolsDir")
     
-    # step 2: determine from used Python interpreter (designer is test object)
+    # step 2: try the qt5_applications package
+    if not path:
+        import qt5_applications
+        path = os.path.join(os.path.dirname(qt5_applications.__file__),
+                            "Qt", "bin")
+    
+    # step 3: determine from used Python interpreter (designer is test object)
     if not path:
         program = "designer"
         if isWindowsPlatform():

eric ide

mercurial